@@ -1,44 +1,31 @@
 import click
-import os
 import time
 import webbrowser
-import pathlib
 import textwrap
 import requests
+
 from datetime import datetime, timedelta
 from halo import Halo
 from typing import Optional, Dict
 from dateutil import parser
 
 from ..auth import TransformAuth
-from ..exceptions import AuthException
+from ..constants import (
+    API_KEY_CONFIG_KEY,
+    BEARER_TOKEN_CONFIG_KEY,
+    PINNED_MODEL_ID_CONFIG_KEY,
+)
 from ..models import ModelKey, UserState
+from ..mql import MQLClient
 
 
 class CLIContext(TransformAuth):  # noqa: D
-
-    API_KEY_CONFIG_KEY = "api_key"
-    BEARER_TOKEN_CONFIG_KEY = "bearer_token"
-    BEARER_TOKEN_EXPIRES_AT_CONFIG_KEY = "bearer_token_expires_at"
-    MQL_OVERRIDE_CONFIG_KEY = "mql_server_url_override"
-    PINNED_MODEL_ID_CONFIG_KEY = "pinned_model_id"
-
     def __init__(self) -> None:  # noqa: D
         self.verbose = False
         self.__user_state: Optional[UserState] = None
-        self.__auth_header: Optional[Dict[str, str]] = None
         self.__just_authenticated = False
-        try:
-            super().__init__()
-        except AuthException:
-            self.prompt_authentication()
-        # Check if the proper directory exists, if not create it
-        if not os.path.exists(self.config.config_dir):
-            cofig_dir = pathlib.Path(self.config.config_dir)
-            cofig_dir.mkdir(parents=True)
-
-        # Trigger auth
-        self.user_state
+        super().__init__()
+        self.mql = MQLClient()
 
     @TransformAuth.api_key.setter
     def api_key(self, api_key: str) -> None:
@@ -50,15 +37,14 @@ class CLIContext(TransformAuth):  # noqa: D
 
     def remove_api_key_and_prompt_browser_login(self) -> None:
         """Remove API key from config and prompt browser login. Used when MFA is newly required for an org."""
-        if self.config._get_config_value(self.API_KEY_CONFIG_KEY) is not None:
-            self.config._remove_config_value(self.API_KEY_CONFIG_KEY)
-        self.__auth_header = None
+        if self.config._get_config_value(API_KEY_CONFIG_KEY) is not None:
+            self.config._remove_config_value(API_KEY_CONFIG_KEY)
         self.prompt_auth0_login()
 
     @property
     def bearer_token(self) -> Optional[str]:
         """Get bearer token from config, if exists."""
-        token = self.config._get_config_value(self.BEARER_TOKEN_CONFIG_KEY)
+        token = self.config._get_config_value(BEARER_TOKEN_CONFIG_KEY)
         if (
             token is not None
             and self.bearer_token_expires_at is not None
@@ -81,22 +67,6 @@ class CLIContext(TransformAuth):  # noqa: D
                 f"✨ Success! We've set your Transform authorization credentials. Please note that these credentials will expire in {expires_in_hours} hours. We're ready to query.\n"
             )
 
-    @property
-    def auth_header(self) -> Dict[str, str]:
-        """Get auth header based on creds in config file. If none, prompt setting them."""
-        if not self.__auth_header:
-            if self.api_key is not None:
-                self.__auth_header = {"Authorization": f"X-Api-Key {self.api_key}"}
-            elif self.bearer_token is not None:
-                self.__auth_header = {"Authorization": f"Bearer {self.bearer_token}"}
-            else:
-                self.prompt_authentication()
-
-        if not self.__auth_header:
-            raise click.ClickException("🔑 No authentication provided. Please run `mql setup` to authenticate.")
-
-        return self.__auth_header
-
     @property
     def is_authenticated(self) -> bool:  # noqa: D
         if self.api_key is not None or self.bearer_token is not None:
@@ -210,7 +180,7 @@ class CLIContext(TransformAuth):  # noqa: D
     def user_state(self) -> UserState:  # noqa: D
         if self.__user_state is None:
             try:
-                self.__user_state = self.backend_client.get_user_state()
+                self.__user_state = self.mql.identify()
             except Exception as e:
                 # TODO: Figure out a better way to determine user's org is blocking API key use without doing hacky string matching!
                 error_msg = str(e)
@@ -223,43 +193,28 @@ class CLIContext(TransformAuth):  # noqa: D
                     raise click.ClickException(error_msg)
         return self.__user_state
 
-    def identify(self) -> None:  # noqa: D
-
-        msg = f"You are authenticated as {self.user.user_name} within the {self.org.name} organization"
-
-        if self.current_model:
-            msg = (
-                msg
-                + f" using model at {self.current_model.repository}/{self.current_model.branch}:{self.current_model.commit}\n"
-                + self.mql_server_url_status
-            )
-        else:
-            msg = (
-                msg
-                + ". There are currently no metrics committed for your org, please see https://app.transformdata.io/install "
-                + "for instructions on how to commit your first Transform metrics."
-            )
-
-        click.echo(msg)
-
     @property
     def pinned_model_id(self) -> Optional[int]:
         """Config override for the org's current model key. Primarily used for development"""
-        out = self.config._get_config_value(self.PINNED_MODEL_ID_CONFIG_KEY)
+        out = self.config._get_config_value(PINNED_MODEL_ID_CONFIG_KEY)
         return int(out) if out else None
 
     @pinned_model_id.setter
     def pinned_model_id(self, model_id: int) -> None:  # noqa: D
         if not model_id:
-            self.config._remove_config_value(self.PINNED_MODEL_ID_CONFIG_KEY)
+            self.config._remove_config_value(PINNED_MODEL_ID_CONFIG_KEY)
 
         # fetch model row to ensure it's valid
-        self.backend_client.get_model_key(model_id)
-        self.config._set_config_value(self.PINNED_MODEL_ID_CONFIG_KEY, str(model_id))
+        self.mql.get_model_key(model_id)
+        self.config._set_config_value(PINNED_MODEL_ID_CONFIG_KEY, str(model_id))
 
     def unpin_model(self) -> None:  # noqa: D
         if self.pinned_model_id:
-            self.config._remove_config_value(self.PINNED_MODEL_ID_CONFIG_KEY)
+            self.config._remove_config_value(PINNED_MODEL_ID_CONFIG_KEY)
+
+    @property
+    def current_model(self) -> Optional[ModelKey]:  # noqa: D
+        return self.user_state.current_model
 
     def resolve_query_model_key(self, config_dir: Optional[str] = None) -> Optional[ModelKey]:
         """Resolve which model key to use for a given query or materialization.
@@ -271,13 +226,13 @@ class CLIContext(TransformAuth):  # noqa: D
         if config_dir:
             spinner = Halo(text="Parsing and uploading local configs…", spinner="dots")
             spinner.start()
-            model_key = self.backend_client.commit_configs(config_dir)
+            model_key = self.mql.commit_configs(config_dir)
             spinner.succeed("🌱 Successfully parsed local configs")
             return model_key
 
         if self.pinned_model_id:
 
-            pinned_model = self.backend_client.get_model_key(self.pinned_model_id)
+            pinned_model = self.mql.get_model_key(self.pinned_model_id)
             msg = textwrap.dedent(
                 f"""\
                     📌 We've found a locally pinned model that we will be using to complete this request, uploaded {pinned_model.created_at}.
@@ -309,6 +264,24 @@ class CLIContext(TransformAuth):  # noqa: D
         else:
             return None
 
+    def identify(self) -> None:  # noqa: D
+        msg = f"You are authenticated as {self.user_state.user.user_name} within the {self.user_state.organization.name} organization"
+
+        if self.user_state.current_model:
+            msg = (
+                msg
+                + f" using model at {self.user_state.current_model.repository}/{self.user_state.current_model.branch}:{self.user_state.current_model.commit}\n"
+                + self.mql_server_url_status
+            )
+        else:
+            msg = (
+                msg
+                + ". There are currently no metrics committed for your org, please see https://app.transformdata.io/install "
+                + "for instructions on how to commit your first Transform metrics."
+            )
+
+        click.echo(msg)
+
     @TransformAuth.mql_server_url_config_override.setter
     def mql_server_url_config_override(self, mql_server_url: str) -> None:  # noqa: D
         TransformAuth.mql_server_url_config_override.fset(self, mql_server_url)
