@@ -1,15 +1,14 @@
 import os
 import ast
 import logging
-from datetime import datetime
-from typing import Callable, List, Optional
-
 import click
 
-from ..models import CacheMode, INF, NEGATIVE_ONE, DEFAULT_LIMIT, TimeGranularity
+from datetime import datetime
+from functools import wraps
+from typing import Callable, List, Optional
 
-DEFAULT_QUERY_TIMEOUT = 180
-POLL_INTERVAL = 1.0
+from ..constants import DEFAULT_QUERY_TIMEOUT
+from ..models import CacheMode, PercentChange, INF, NEGATIVE_ONE, DEFAULT_LIMIT, TimeGranularity
 
 
 class PythonLiteralOption(click.Option):
@@ -139,6 +138,16 @@ def query_options(function: Callable) -> Callable:
         callback=lambda ctx, param, value: TimeGranularity(value) if value is not None else None,
     )(function)
 
+    function = click.option(
+        "--time-comparison",
+        type=click.Choice(
+            list(map(lambda x: x.value, PercentChange)),
+            case_sensitive=False,
+        ),
+        # Cast as PercentChange type
+        callback=lambda ctx, param, value: PercentChange(value) if value is not None else None,
+    )(function)
+
     return function
 
 
@@ -183,7 +192,7 @@ def __validate_and_normalize_query_inputs(option_name: str, value: List[str]) ->
         if "," in v:
             return [i.strip() for i in v.split(",")]
 
-    return value
+    return list(value)
 
 
 def no_active_mql_servers(org_name: str) -> None:
@@ -221,3 +230,19 @@ def enable_debug_log_file() -> None:  # noqa: D
 def get_query_logs_url_for_id(query_id: str) -> str:
     """Returns the query log URL to the web UI given the query_id"""
     return f"https://app.transformdata.io/mql/query/{query_id}?tab=server_logs"
+
+
+def exception_handler(func):
+    """Decorator to handle exceptions
+
+    TODO: handle custom exceptions
+    """
+
+    @wraps(func)
+    def wrapper(*args, **kwargs):
+        try:
+            func(*args, **kwargs)
+        except Exception as e:
+            click.echo(f"\nERROR: {str(e)}")
+
+    return wrapper
