@@ -23,9 +23,9 @@ from .cli_utils import (
     enable_debug_log_file,
     get_query_logs_url_for_id,
     query_observability_options,
+    exception_handler,
 )
-from ..models import CacheMode, HealthReportStatus, DEFAULT_LIMIT, INF, NEGATIVE_ONE, TimeGranularity
-from ..interfaces import MQLInterface
+from ..models import CacheMode, PercentChange, HealthReportStatus, DEFAULT_LIMIT, INF, NEGATIVE_ONE, TimeGranularity
 from .. import PACKAGE_NAME, __version__
 
 pass_config = click.make_pass_decorator(CLIContext, ensure=True)
@@ -106,6 +106,7 @@ def contact(config: CLIContext) -> None:
     default=False,
 )
 @pass_config
+@exception_handler
 def setup(
     config: CLIContext,
     api_key: Optional[str],
@@ -155,6 +156,7 @@ def setup(
 
 @cli.command()
 @pass_config
+@exception_handler
 def identify(config: CLIContext) -> None:
     """Identify the currently authenticated user."""
     config.identify()
@@ -169,6 +171,7 @@ def version(config: CLIContext) -> None:
 
 @cli.command()
 @pass_config
+@exception_handler
 @click.option("--force", "-f", is_flag=True, default=False)
 def drop_cache(config: CLIContext, force: bool) -> None:
     """Drop the MQL cache. Only necessary if there is evidence cache corruption."""
@@ -185,7 +188,7 @@ def drop_cache(config: CLIContext, force: bool) -> None:
     spinner = Halo(text="Initiating drop-cache query... this can take a little while", spinner="dots")
     spinner.start()
 
-    resp = config.mql_client.drop_cache()
+    resp = config.mql.drop_cache()
     if not resp:
         raise click.ClickException("‼️ Failed to drop the cache.")
     spinner.succeed("💥 Successfully dropped MQL cache.")
@@ -193,10 +196,11 @@ def drop_cache(config: CLIContext, force: bool) -> None:
 
 @cli.command()
 @pass_config
+@exception_handler
 def ping(config: CLIContext) -> None:
     """Perform basic HTTP health check against configured MQL server."""
     tic = time.perf_counter()
-    resp = config.mql_client.ping()
+    resp = config.mql.ping()
     click.echo(
         f"🏓 Received HTTP {resp.status_code} code from MQL in {time.perf_counter() - tic:0.4f} seconds. \n {resp.text}"
     )
@@ -204,9 +208,10 @@ def ping(config: CLIContext) -> None:
 
 @cli.command()
 @pass_config
+@exception_handler
 def list_servers(config: CLIContext) -> None:
     """Lists available MQL servers."""
-    servers = config.backend_client.get_org_mql_servers()
+    servers = config.mql.list_servers()
     if len(servers) == 0:
         no_active_mql_servers(config.org.name)
         exit()
@@ -219,9 +224,10 @@ def list_servers(config: CLIContext) -> None:
 
 @cli.command()
 @pass_config
+@exception_handler
 def health_report(config: CLIContext) -> None:
     """Completes a health check on MQL servers."""
-    servers = config.backend_client.get_org_mql_servers()
+    servers = config.mql.health_report()
     if len(servers) == 0:
         no_active_mql_servers(config.org.name)
         exit()
@@ -230,20 +236,17 @@ def health_report(config: CLIContext) -> None:
         f"🏥 Health Report for {len(servers)} MQL Servers at {config.org.name}",
     )
     for s in servers:
-        mql_client = MQLInterface(config.auth_header, s.url)
-        try:
-            version, health = mql_client.get_health_report()
-            click.echo(f"• {click.style(s.name, bold=True, fg='yellow')}: {s.url} running commit {version}")
-            for h in health:
+        if s.status == HealthReportStatus.FAIL:
+            click.echo(
+                f"• ❌ {click.style(s.name, bold=True, fg=('red'))}:  Unable to connect to MQL server at url {s.url}."
+            )
+        else:
+            click.echo(f"• {click.style(s.name, bold=True, fg='yellow')}: {s.url} running commit {s.version}")
+            for h in s.servers:
                 if h.status == HealthReportStatus.SUCCESS.value:
                     click.echo(f"  • ✅ {click.style(h.name, bold=True, fg=('green'))}: No Errors")
                 else:
                     click.echo(f"  • ❌ {click.style(h.name, bold=True, fg=('red'))}:  {h.error_message}")
-        except Exception:
-            click.echo(
-                f"• ❌ {click.style(s.name, bold=True, fg=('red'))}:  Unable to connect to MQL server at url {s.url}."
-            )
-            continue
 
 
 @cli.command()
@@ -271,6 +274,7 @@ def health_report(config: CLIContext) -> None:
     help="In the query output, show the query that was executed against the data warehouse",
 )
 @query_observability_options
+@exception_handler
 def query(
     ctx: click.core.Context,
     config: CLIContext,
@@ -281,6 +285,7 @@ def query(
     where: Optional[str] = None,
     time_constraint: Optional[str] = None,
     time_granularity: Optional[TimeGranularity] = None,
+    time_comparison: Optional[PercentChange] = None,
     order: Optional[List[str]] = None,
     limit: Optional[str] = None,
     cache_mode: Optional[CacheMode] = None,
@@ -306,19 +311,20 @@ def query(
     start = time.time()
     spinner = Halo(text="Initiating query…", spinner="dots")
     spinner.start()
-
-    query_id = config.mql_client.create_query(
-        model_key=model_key,
+    query_id = config.mql.create_query(
+        model_key_id=model_key.id if model_key else None,
         metrics=metrics,
         dimensions=dimensions,
-        where_constraint_str=where,
+        where=where,
         time_constraint=time_constraint,
-        time_granularity=time_granularity,
+        time_granularity=time_granularity.value if time_granularity else None,
+        time_comparison=time_comparison.value if time_comparison else None,
         order=order,
         limit=limit,
-        cache_mode=cache_mode,
+        cache_mode=cache_mode.value if cache_mode else None,
         as_table=as_table,
-    )
+    ).query_id
+
     spinner.succeed(f"Query initialized: {query_id}")
     if detach:
         return
@@ -333,7 +339,7 @@ def query(
 
     df: Optional[pd.DataFrame] = None
     try:
-        df = config.mql_client.get_query_dataframe(query_id, timeout)
+        df = config.mql.get_query_dataframe(query_id, timeout)
         final_message = f"Success 🦄 - query completed after {time.time() - start:.2f} seconds"
         final_symbol = LogSymbols.SUCCESS
     except Exception as e:
@@ -382,6 +388,7 @@ def query(
 @query_observability_options
 @pass_config
 @click.pass_context
+@exception_handler
 def drop_materialization(
     ctx: click.core.Context,
     config: CLIContext,
@@ -416,12 +423,12 @@ def drop_materialization(
     spinner = Halo(text="Initiating drop materialization query…", spinner="dots")
     spinner.start()
 
-    query_id = config.mql_client.drop_materialization(
-        model_key=model_key,
+    query_id = config.mql.drop_materialization(
+        model_key_id=model_key.id if model_key else None,
         materialization_name=materialization_name,
         start_time=start_time,
         end_time=end_time,
-    )
+    ).query_id
 
     spinner.succeed(f"Query initialized: {query_id}")
     if detach:
@@ -429,7 +436,7 @@ def drop_materialization(
 
     spinner.start("Waiting for query")
     try:
-        config.mql_client.get_drop_materialization_result(query_id, timeout)
+        config.mql.poll_for_query_completion(query_id, timeout)
         final_message = f"Success 🦄 - drop materialization query completed after {time.time() - start:.2f} seconds."
         final_symbol = LogSymbols.SUCCESS
     except Exception as e:
@@ -474,6 +481,7 @@ def drop_materialization(
 @query_observability_options
 @pass_config
 @click.pass_context
+@exception_handler
 def materialize(
     ctx: click.core.Context,
     config: CLIContext,
@@ -508,13 +516,13 @@ def materialize(
     spinner = Halo(text="Initiating materialization query…", spinner="dots")
     spinner.start()
 
-    query_id = config.mql_client.create_materialization(
-        model_key=model_key,
+    query_id = config.mql.create_materialization(
+        model_key_id=model_key.id if model_key else None,
         materialization_name=materialization_name,
         start_time=start_time,
         end_time=end_time,
         output_table=output_table,
-    )
+    ).query_id
 
     spinner.succeed(f"Query initialized: {query_id}")
     if detach:
@@ -522,7 +530,7 @@ def materialize(
 
     spinner.start("Waiting for query")
     try:
-        schema, table = config.mql_client.get_materialization_result(query_id, timeout)
+        schema, table = config.mql.get_materialization_result(query_id, timeout)
         materialized_at = f"Materialized table: {schema}.{table}" if schema is not None else ""
         final_message = (
             f"Success 🦄 - materialize query completed after {time.time() - start:.2f} seconds." f"{materialized_at}"
@@ -543,12 +551,13 @@ def materialize(
 
 @cli.command()
 @pass_config
+@exception_handler
 @click.option("--search", required=False, type=str, help="Filter available materializations by this search term")
 def list_materializations(config: CLIContext, search: Optional[str] = None) -> None:
     """List the materializations for the Organization with their available metrics and dimensions."""
 
     model_key = config.resolve_query_model_key()
-    materializations = sorted(config.mql_client.get_materializations(model_key), key=lambda m: m.name)
+    materializations = config.mql.list_materializations(model_key.id if model_key else None)
     if not materializations:
         click.echo("List of materializations unavailable.")
 
@@ -589,6 +598,7 @@ def list_materializations(config: CLIContext, search: Optional[str] = None) -> N
 @pass_config
 @click.option("--search", required=False, type=str, help="Filter available metrics by this search term")
 @click.option("--show-all-dims", is_flag=True, default=False, help="Show all dimensions associated with a metric.")
+@exception_handler
 def list_metrics(config: CLIContext, show_all_dims: bool = False, search: Optional[str] = None) -> None:
     """List the metrics for the Organization with their available dimensions.
 
@@ -598,7 +608,7 @@ def list_metrics(config: CLIContext, show_all_dims: bool = False, search: Option
     # Note: calling config.resolve_query_model_key may initiate a dialog if the user has a pinned model
     # Purposefully pulling this out before the spinner
     model_key = config.resolve_query_model_key()
-    metrics = sorted(config.mql_client.get_metrics(model_key), key=lambda m: m.name)
+    metrics = sorted(config.mql.list_metrics(model_key.id if model_key else None).values(), key=lambda m: m.name)
     if not metrics:
         click.echo("List of metrics unavailable.")
 
@@ -627,6 +637,7 @@ def list_metrics(config: CLIContext, show_all_dims: bool = False, search: Option
 @cli.command()
 @pass_config
 @click.option("--query-id", required=True, type=str, help="Query ID to stream logs for")
+@exception_handler
 def stream_query_logs(
     config: CLIContext,
     query_id: str,
@@ -657,13 +668,14 @@ def stream_query_logs(
 @click.option("--active-only", type=bool, default=False, help="Return active queries only")
 @click.option("--limit", required=False, type=int, help="Limit the number of queries retrieved: syntax is --limit 100")
 @pass_config
+@exception_handler
 def list_queries(
     config: CLIContext,
     active_only: bool,
     limit: Optional[int] = None,
 ) -> None:
     """Retrieve queries from mql server"""
-    click.echo(config.mql_client.get_queries(active_only=active_only, limit=limit))
+    click.echo(config.mql.list_queries(active_only=active_only, limit=limit))
 
 
 @cli.command()
@@ -671,7 +683,7 @@ def list_queries(
 @pass_config
 def validate_configs(config: CLIContext, config_dir: str) -> None:
     """Validate yaml configs found in specified config directory"""
-    repo, branch, commit = config.backend_client.validate_configs(config_dir)
+    repo, branch, commit = config.mql.validate_configs(config_dir)
     click.echo(f"🎉 Successfully validated configs for commit ({commit}) in repo ({repo}), on branch ({branch})")
 
 
@@ -680,11 +692,12 @@ def validate_configs(config: CLIContext, config_dir: str) -> None:
 @click.option("--pin", type=bool, required=False, help="Whether to pin the model or not")
 @pass_config
 @click.pass_context
+@exception_handler
 def commit_configs(ctx: click.core.Context, config: CLIContext, config_dir: str, pin: bool = None) -> None:
     """Commit yaml configs found in specified config directory"""
     spinner = Halo(text="Parsing and uploading configs…", spinner="dots")
     spinner.start()
-    model = config.backend_client.commit_configs(config_dir)
+    model = config.mql.commit_configs(config_dir)
     spinner.succeed(
         f"🦄 Successfully committed configs id {model.id} on branch {model.branch} with commit {model.commit}"
     )
@@ -710,6 +723,7 @@ def commit_configs(ctx: click.core.Context, config: CLIContext, config_dir: str,
 @cli.command()
 @click.option("--model-id", type=int, required=True, help="Model id to pin for local queries")
 @pass_config
+@exception_handler
 def pin_model(config: CLIContext, model_id: int) -> None:
     """Pin a model id from configs that are already committed to the MQL Server"""
     try:
@@ -731,7 +745,7 @@ def pin_model(config: CLIContext, model_id: int) -> None:
     click.echo(
         textwrap.dedent(
             f"""\
-            ✅ Succesfully pinned model {model_id}.
+            ✅ Successfully pinned model {model_id}.
             💡 Unpin this model in the future:
 
                 mql unpin-model
@@ -743,13 +757,14 @@ def pin_model(config: CLIContext, model_id: int) -> None:
 
 @cli.command()
 @pass_config
+@exception_handler
 def unpin_model(config: CLIContext) -> None:
     """Unpin a model id"""
     config.unpin_model()
     click.echo(
         textwrap.dedent(
             """\
-                ✅ Succesfully unpinned model and reverted to default configs.
+                ✅ Successfully unpinned model and reverted to default configs.
                 💡 Commit and pin new configs:
 
                     mql commit-configs --config-dir <path> --pin true
@@ -759,5 +774,25 @@ def unpin_model(config: CLIContext) -> None:
     )
 
 
+@cli.command()
+@pass_config
+@exception_handler
+def latest_mql_image(config: CLIContext) -> None:
+    """Outputs the latest MQL server image details"""
+
+    server_image = config.mql.latest_mql_image()
+    click.echo(
+        textwrap.dedent(
+            f"""\
+                ✅ Successfully retrieved the latest MQL server image,
+                    Service Name: {server_image.service_name}
+                    Version Hash: {server_image.version_hash}
+                    Download URL: {server_image.download_url}
+
+            """
+        )
+    )
+
+
 if __name__ == "__main__":
     cli()
