@@ -12,8 +12,9 @@ from gql import Client, gql  # type: ignore
 from gql.transport.requests import RequestsHTTPTransport  # type: ignore
 
 from transform_tools.validate import upload_configs, ERROR_RESPONSE_PREFIX
+from .constants import DEFAULT_QUERY_TIMEOUT
 from .exceptions import QueryRuntimeException
-from .utils import get_git_info, is_git_repo, local_commit_info, DEFAULT_QUERY_TIMEOUT, POLL_INTERVAL
+from .utils import resolve_local_commit_info
 from .models import (
     MqlQueryStatus,
     MqlQueryStatusResp,
@@ -25,6 +26,8 @@ from .models import (
     ModelKey,
     Metric,
     MQLServer,
+    MQLServerImage,
+    PercentChange,
     HealthReport,
     UserState,
     TimeGranularity,
@@ -94,7 +97,7 @@ class BaseInterface:
             else:
                 raise
         finally:
-            logger.debug(f"Query {query} took {(time.time() - start_time):.2f}s")
+            logger.debug(f"Query for {' '.join(response.keys())} took {(time.time() - start_time):.2f}s")
         return response
 
     @property
@@ -123,20 +126,14 @@ class BackendInterface(BaseInterface):  # noqa: D
 
     def validate_configs(self, config_dir: str) -> Tuple[str, str, str]:  # noqa: D
         """Finds and validates yaml configs in the provided directory"""
-        if is_git_repo(config_dir):
-            repo, branch, commit = get_git_info(config_dir)
-        else:
-            repo, branch, commit = local_commit_info()
-
-        commit += "-dirty"
+        repo, branch, commit = resolve_local_commit_info(config_dir)
         self._get_and_upload_configs("validate", config_dir, repo, branch, commit)
 
         return repo, branch, commit
 
     def commit_configs(self, config_dir: str) -> ModelKey:
         """Finds and validates yaml configs in the provided directory"""
-        repo, branch, commit = get_git_info()
-        commit += "-dirty"
+        repo, branch, commit = resolve_local_commit_info(config_dir)
         r = self._get_and_upload_configs("commit", config_dir, repo, branch, commit)
 
         return ModelKey.from_snake_dict(r.json()["model"])
@@ -281,6 +278,21 @@ class BackendInterface(BaseInterface):  # noqa: D
 
         return UserState(user=user, organization=org, current_model=model)
 
+    def get_latest_mql_server_image(self) -> MQLServerImage:
+        """Fetch the latest mql server image."""
+        query = gql(
+            """
+            query MqlLatestServerQuery {
+                latestMqlServer {
+                    serviceName
+                    versionHash
+                    downloadUrl
+                }
+            }
+            """
+        )
+        return MQLServerImage.from_gql_dict(self.execute(query)["latestMqlServer"])
+
 
 class MQLInterface(BaseInterface):  # noqa: D
     def __init__(self, auth_header: Dict[str, str], query_server_url: str) -> None:  # noqa: D
@@ -294,6 +306,7 @@ class MQLInterface(BaseInterface):  # noqa: D
         where_constraint: Optional[str] = None,
         time_constraint: Optional[str] = None,
         time_granularity: Optional[TimeGranularity] = None,
+        time_comparison: Optional[PercentChange] = None,
         order: Optional[List[str]] = None,
         limit: Optional[str] = None,
         cache_mode: Optional[CacheMode] = None,
@@ -315,6 +328,7 @@ class MQLInterface(BaseInterface):  # noqa: D
             "whereConstraint": where_constraint,
             "timeConstraint": time_constraint,
             "timeGranularity": time_granularity.name if time_granularity else None,
+            "pctChange": time_comparison.name if time_comparison else None,
             "order": order,
             "limit": limit,
             "cacheMode": (CacheMode.default() if cache_mode is None else cache_mode).name,
@@ -524,6 +538,35 @@ class MQLInterface(BaseInterface):  # noqa: D
             )["metrics"]
         ]
 
+    def get_metric(self, metric_name: str, model_key: Optional[ModelKey] = None):  # noqa: D
+        query = gql(
+            """
+            query MetricQuery($modelKey: ModelKeyInput, $metricName: String!) {
+                metricByName(modelKey: $modelKey, name: $metricName) {
+                    name
+                    measures
+                    dimensions
+                }
+            }
+            """
+        )
+        return Metric.from_gql_dict(
+            self.execute(
+                query,
+                variable_values={
+                    "modelKey": {
+                        "organization": model_key.organization_id,
+                        "repo": model_key.repository,
+                        "branch": model_key.branch,
+                        "commit": model_key.commit,
+                    }
+                    if model_key
+                    else None,
+                    "metricName": metric_name,
+                },
+            )["metricByName"]
+        )
+
     def create_query(  # noqa: D
         self,
         metrics: List[str],
@@ -532,6 +575,7 @@ class MQLInterface(BaseInterface):  # noqa: D
         where_constraint_str: Optional[str] = None,
         time_constraint: Optional[str] = None,
         time_granularity: Optional[TimeGranularity] = None,
+        time_comparison: Optional[PercentChange] = None,
         order: Optional[List[str]] = None,
         limit: Optional[str] = None,
         cache_mode: Optional[CacheMode] = None,
@@ -539,14 +583,9 @@ class MQLInterface(BaseInterface):  # noqa: D
     ) -> str:
         """Implements CreateMqlQuery mutation in MQL/GQL"""
 
-        # Unless we are requesting multiple metrics, include the post-processor required by the UI
-        # so that users are able to visualize the results in the query logs
-        if len(metrics) > 1 or len(dimensions) > 1:
-            time_series = False
-            result_format = None
-        else:
-            time_series = True
-            result_format = "TFD"
+        # TODO: Find a fix to being able to show cli query graph on server logs
+        time_series = False
+        result_format = None
         query = gql(
             """
             mutation CreateMqlQueryMutation(
@@ -562,6 +601,7 @@ class MQLInterface(BaseInterface):  # noqa: D
                 $asTable: String,
                 $timeSeries: Boolean,
                 $resultFormat: ResultFormat,
+                $pctChange: PercentChange,
             ) {
                 createMqlQuery(
                     input: {
@@ -576,7 +616,8 @@ class MQLInterface(BaseInterface):  # noqa: D
                         cacheMode: $cacheMode,
                         asTable: $asTable,
                         addTimeSeries: $timeSeries,
-                        resultFormat: $resultFormat
+                        resultFormat: $resultFormat,
+                        pctChange: $pctChange,
                     }
                 ) {
                     id
@@ -592,6 +633,7 @@ class MQLInterface(BaseInterface):  # noqa: D
             where_constraint=where_constraint_str,
             time_constraint=time_constraint,
             time_granularity=time_granularity,
+            time_comparison=time_comparison,
             order=order,
             limit=limit,
             cache_mode=cache_mode,
@@ -767,23 +809,22 @@ class MQLInterface(BaseInterface):  # noqa: D
         start = time.time()
 
         # Poll until the query is complete or we hit the timeout (timeout of 0 indicate no timeout)
+        poll_interval = 0.1
         while timeout == 0 or time.time() < start + timeout:
-            time.sleep(POLL_INTERVAL)
             query_result = self.get_query_status(query_id)
             if query_result.is_complete:
                 return query_result
+            time.sleep(poll_interval)
+
+            # poll interval starts very low and gets longer until we hit a maximum of 5s
+            # allows us to resolve fast queries quickly without hammering mql for long queries
+            poll_interval = min(5, poll_interval * 1.5)
 
         raise QueryRuntimeException(
             query_id,
             f"Timeout reached waiting for query {query_id} to complete after {timeout} seconds. Please see --timeout option to override.",
         )
 
-    def get_drop_materialization_result(self, query_id: str, timeout: Optional[int] = None) -> None:
-        """Retrieves status of drop materialization query"""
-        resp = self.poll_for_query_completion(query_id, timeout=timeout)
-        if not resp.is_successful:
-            raise QueryRuntimeException.from_query_response(resp)
-
     def get_materialization_result(self, query_id: str, timeout: Optional[int] = None) -> Tuple[str, str]:
         """Retrieves materialized table resulting from successful materialization query"""
         resp = self.poll_for_query_completion(query_id, timeout=timeout)
