@@ -284,7 +284,34 @@ class MqlMaterializeResp:
 
     schema: Optional[str]
     table: Optional[str]
+    query_id: str
 
     @property
     def fully_qualified_name(self) -> str:  # noqa: D
         return f"{self.schema}.{self.table}"
+
+
+@dataclass(frozen=True)
+class MQLServerImage:
+    """Object to represent a MQL Server Image."""
+
+    service_name: str
+    version_hash: str
+    download_url: str
+
+    @classmethod
+    def from_gql_dict(cls, _input: Dict[str, str]) -> "MQLServerImage":  # noqa: D
+        return cls(
+            service_name=_input["serviceName"],
+            version_hash=_input["versionHash"],
+            download_url=_input["downloadUrl"],
+        )
+
+
+class PercentChange(Enum):
+    """Used to calculate the percent change between the given granularity."""
+
+    WOW = "wow"  # week-over-week
+    MOM = "mom"  # month-over-month
+    QOQ = "qoq"  # quarter-over-quarter
+    YOY = "yoy"  # year-over-year
